@@ -9,32 +9,26 @@
 mundo = None
 bg = None
 
-import console
 import sys
 import utils
 from mundo import Mundo
 import actores
+import escena
+import escenas
 import fondos
 import habilidades
-import eventos
 import sonidos
 import musica
 import colores
+import demos
 import atajos
-import escenas
 import interfaz
-import log
-
-try:
-    import aplicacion
-    try:
-        import ejemplos
-    except ImportError:
-        # Los ejemplos están en un paquete separado, solo se importa si el paquete está instalado
-        pass
-except ImportError:
-    print "ERROR: no está disponible PyQt4"
+import interprete
+from pilas.escena import Normal
 
+# Permite cerrar el programa usando CTRL+C
+import signal
+signal.signal(signal.SIGINT, signal.SIG_DFL)
 
 __doc__ = """
 Módulo pilas
@@ -48,11 +42,9 @@ Este módulo contiene las funciones principales
 para iniciar y ejecutar la biblioteca.
 """
 
-if utils.esta_en_sesion_interactiva():
-    utils.cargar_autocompletado()
-
 def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
-            rendimiento=60, modo='detectar', gravedad=(0, -90), pantalla_completa=False):
+            rendimiento=60, modo='detectar', gravedad=(0, -90), pantalla_completa=False,
+            permitir_depuracion=True):
     """
     Inicia la ventana principal del juego con algunos detalles de funcionamiento.
 
@@ -72,31 +64,58 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
     :modo: si se utiliza modo interactivo o no.
     :gravedad: el vector de aceleracion para la simulacion de fisica.
     :pantalla_completa: si debe usar pantalla completa o no.
+    :permitir_depuracion: si se desea tener habilidatas las funciones de depuracion de las teclas F5 a F12
 
     """
 
     global mundo
 
-    motor = _crear_motor(usar_motor)
+    if not esta_inicializada():
+        motor = _crear_motor(usar_motor, permitir_depuracion)
 
-    if motor:
-        mundo = Mundo(motor, ancho, alto, titulo, rendimiento, gravedad, pantalla_completa)
-        escenas.Normal(colores.grisclaro)
+        if motor:
+            mundo = Mundo(motor, ancho, alto, titulo, rendimiento, gravedad, pantalla_completa)
+            mundo.gestor_escenas.cambiar_escena(Normal())
 
-def iniciar_con_asistente(ancho=640, alto=480, titulo='Pilas',
-            rendimiento=60, modo='detectar', gravedad=(0, -90), imagen="asistente.png"):
+            if _usa_interprete_lanas():
+                mundo.motor.ventana.show()
+    else:
+        mundo.motor.modificar_ventana(ancho, alto, titulo, pantalla_completa)
+        mundo.fisica.definir_gravedad(*gravedad)
+
+
+def esta_inicializada():
+    "Indica si la biblioteca pilas ha sido inicializada con pilas.iniciar()"
+    global mundo
+    return isinstance(mundo, Mundo)
+
+
+def iniciar_con_lanzador(ancho=640, alto=480, titulo='Pilas',
+            rendimiento=60, modo='detectar', gravedad=(0, -90), imagen="asistente.png",
+            permitir_depuracion=True):
     """Identica a la función iniciar, solo que permite al usuario seleccionar
     el motor multimedia y el modo de video a utilizar.
 
     Esta función es útil cuando se quiere distribuir un juego y no se conoce
     exáctamente el equipo del usuario.
     """
+    import lanzador
 
+    usar_motor, pantalla_completa = lanzador.ejecutar(imagen, titulo)
+    iniciar(ancho, alto, titulo, usar_motor, rendimiento, modo, gravedad, pantalla_completa, permitir_depuracion)
+
+
+def abrir_asistente():
+    """Abre una ventana que permite iniciar pilas graficamente.
+
+    Las opciones que ofrece son "leer el manual" (si esta disponible),
+    "abrir un interprete", "explorar los ejemplos" etc.
+
+    Esta ventana se ha diseñado para mostrarse a los nuevos usuarios
+    de pilas, por ejemplo cuando eligen abrir pilas desde el icono principal.
+    """
     import asistente
-
-    usar_motor, pantalla_completa = asistente.ejecutar(imagen, titulo)
-    iniciar(ancho, alto, titulo, usar_motor, rendimiento, modo, gravedad, pantalla_completa)
-
+    asistente.ejecutar()
 
 def ejecutar(ignorar_errores=False):
     """Pone en funcionamiento las actualizaciones y dibujado.
@@ -118,22 +137,31 @@ def version():
     import pilasversion
     return pilasversion.VERSION
 
-def _crear_motor(usar_motor):
+def _crear_motor(usar_motor, permitir_depuracion):
     """Genera instancia del motor multimedia en base a un nombre.
 
     Esta es una función interna y no debe ser ejecutada
     excepto por el mismo motor pilas."""
 
-    if usar_motor in ['qt', 'qtgl', 'qtsugar', 'qtsugargl']:
+    if usar_motor in ['qt', 'qtgl', 'qtwidget', 'qtsugar', 'qtsugargl']:
         from motores import motor_qt
-        motor = motor_qt.Motor(usar_motor)
+
+        if _usa_interprete_lanas():
+            usar_motor = 'qtsugar'
+
+        motor = motor_qt.Motor(usar_motor, permitir_depuracion)
     else:
         print "El motor multimedia seleccionado (%s) no esta disponible" %(usar_motor)
-        print "Las opciones de motores que puedes probar son 'qt', 'qtgl', 'qtsugar' y 'qtsugargl'."
+        print "Las opciones de motores que puedes probar son 'qt', 'qtgl', 'qtwidget', 'qtsugar' y 'qtsugargl'."
         motor = None
 
     return motor
 
+def _usa_interprete_lanas():
+    "Retorna True si se ha iniciado pilas desde lanas"
+    import os
+    return os.environ.has_key('lanas')
+
 def reiniciar():
     """Elimina todos los actores y vuelve al estado inicial."""
     mundo.reiniciar()
@@ -169,7 +197,7 @@ def abrir_cargador():
 
     return []
 
-def abrir_interprete():
+def abrir_interprete(parent=None, do_raise=False):
     """Abre un intérprete interactivo de python con una ventana.
 
     Esta función se ejecuta cuando un usuario escribe::
@@ -178,6 +206,27 @@ def abrir_interprete():
 
     en una consola del sistema.
     """
+    interprete.main(parent, do_raise)
 
-    import aplicacion
-    aplicacion.main()
+def log(*parametros):
+    eventos.log.emitir(data=parametros)
+
+interpolar = utils.interpolar
+
+def escena_actual():
+    return mundo.gestor_escenas.escena_actual()
+
+def cambiar_escena(escena):
+    mundo.gestor_escenas.cambiar_escena(escena)
+
+def almacenar_escena(escena):
+    mundo.gestor_escenas.almacenar_escena(escena)
+
+def recuperar_escena():
+    mundo.gestor_escenas.recuperar_escena()
+
+
+# Representa el viejo acceso al modulo eventos, pero convierte cada uno
+# de los eventos en una referencia al evento dentro de la escena actual.
+from evento import ProxyEventos
+eventos = ProxyEventos()
