@@ -66,11 +66,14 @@ class Actor(object, Estudiante):
         self.centro = ('centro', 'centro')
 
         self.id = ""
-
+        
         self.x = x
         self.y = y
         self.transparencia = 0
 
+        # Define en que escena se encuentra el actor.
+        self.escena = None
+
         # Define el nivel de lejanía respecto del observador.
         self.z = 0
         self._espejado = False
@@ -78,6 +81,7 @@ class Actor(object, Estudiante):
         pilas.actores.utils.insertar_como_nuevo_actor(self)
         self._transparencia = 0
         self.anexados = []
+        self._vivo = True
 
     def definir_centro(self, (x, y)):
         if type(x) == str:
@@ -237,7 +241,6 @@ class Actor(object, Estudiante):
     def set_fijo(self, fijo):
         self._actor.fijo = fijo
 
-
     espejado = property(get_espejado, set_espejado, doc="Indica si se tiene que invertir horizonaltamente la imagen del actor.")
     z = property(get_z, set_z, doc="Define lejania respecto del observador.")
     x = property(get_x, set_x, doc="Define la posición horizontal.")
@@ -252,14 +255,17 @@ class Actor(object, Estudiante):
 
     def eliminar(self):
         """Elimina el actor de la lista de actores que se imprimen en pantalla."""
-        self.destruir()
         self._eliminar_anexados()
+        self.destruir()
 
     def destruir(self):
         """Elimina a un actor pero de manera inmediata."""
-        pilas.actores.utils.eliminar_un_actor(self)
+        self._vivo = False
         self.eliminar_habilidades()
         self.eliminar_comportamientos()
+        # Solo permite eliminar el actor si está en su escena.
+        if self in pilas.escena_actual().actores: 
+            pilas.escena_actual().actores.remove(self)
 
     def actualizar(self):
         """Actualiza el estado del actor.
@@ -299,7 +305,7 @@ class Actor(object, Estudiante):
     izquierda = property(get_izquierda, set_izquierda)
 
     def get_derecha(self):
-        return self.izquierda + self.obtener_ancho()
+        return self.izquierda + self.obtener_ancho() * self.escala
 
     @pilas.utils.interpolable
     def set_derecha(self, x):
@@ -308,7 +314,7 @@ class Actor(object, Estudiante):
     derecha = property(get_derecha, set_derecha)
 
     def get_abajo(self):
-        return self.get_arriba() - self.alto
+        return self.get_arriba() - self.alto * self.escala
 
     @pilas.utils.interpolable
     def set_abajo(self, y):
@@ -408,7 +414,9 @@ class Actor(object, Estudiante):
 
     def esta_fuera_de_la_pantalla(self):
         "Indica si el actor está fuera del area visible de la pantalla."
-        izquierda, derecha, arriba, abajo = pilas.mundo.camara.obtener_area_visible()
+        if self.fijo:
+            return False
+        izquierda, derecha, arriba, abajo = self.escena.camara.obtener_area_visible()
         return self.derecha < izquierda or self.izquierda > derecha or self.abajo > arriba or self.arriba < abajo
 
     def es_fondo(self):
