@@ -2,23 +2,30 @@
 import pilas
 from pilas.actores.globo import Globo
 
+
 class GloboElegir(Globo):
-    
+
     def __init__(self, texto, opciones, funcion_a_invocar, x=0, y=0, dialogo=None):
         self.dialogo = dialogo
         self.opciones = opciones
         self.funcion_a_invocar = funcion_a_invocar
-        espacio = "\n" * (len(opciones) +1)   # representa un espacio en blanco para poner la seleccion
-        Globo.__init__(self, texto + espacio, x, y, dialogo=dialogo)
-    
+
         self.lista_seleccion = pilas.interfaz.ListaSeleccion(opciones, self._cuando_selecciona_opcion, x, y)
         self.lista_seleccion.escala = 0.1
         self.lista_seleccion.escala = [1], 0.2
-        
+        self.lista_seleccion.z = 1
+
+        Globo.__init__(self, texto, x, y, dialogo=dialogo, 
+                       ancho_globo=self.lista_seleccion.ancho_opciones+24,
+                       alto_globo=self.lista_seleccion.alto_opciones + (self.lista_seleccion.separacion_entre_opciones * len(self.opciones) * 2))
+        self.z = 2
+
     def colocar_origen_del_globo(self, x, y):
+        Globo.colocar_origen_del_globo(self, x, y)
+        
         self.lista_seleccion.centro = ("derecha", "abajo")
-        self.lista_seleccion.x = x - 10
-        self.lista_seleccion.y = y - 10
+        self.lista_seleccion.x = x - (self.ancho_globo - self.lista_seleccion.ancho_opciones) + 12 
+        self.lista_seleccion.y = y + 35
 
     def _obtener_area_para_el_texto(self, texto):
         ancho, alto = self.lienzo.obtener_area_de_texto(texto, tamano=14)
