@@ -28,12 +28,12 @@ class Menu(Actor):
         self.activar()
 
     def activar(self):
-        pilas.eventos.mueve_mouse.conectar(self.cuando_mueve_el_mouse)
-        pilas.eventos.click_de_mouse.conectar(self.cuando_hace_click_con_el_mouse)
+        self.escena.mueve_mouse.conectar(self.cuando_mueve_el_mouse)
+        self.escena.click_de_mouse.conectar(self.cuando_hace_click_con_el_mouse)
 
     def desactivar(self):
-        pilas.eventos.mueve_mouse.desconectar(self.cuando_mueve_el_mouse)
-        pilas.eventos.click_de_mouse.desconectar(self.cuando_hace_click_con_el_mouse)
+        self.escena.mueve_mouse.desconectar(self.cuando_mueve_el_mouse)
+        self.escena.click_de_mouse.desconectar(self.cuando_hace_click_con_el_mouse)
 
     def crear_texto_de_las_opciones(self, opciones):
         "Genera un actor por cada opcion del menu."
@@ -59,14 +59,14 @@ class Menu(Actor):
         "Se ejecuta de manera periodica."
 
         if self.demora_al_responder < 0:
-            if pilas.mundo.control.boton:
+            if pilas.escena_actual().control.boton:
                 self.seleccionar_opcion_actual()
                 self.demora_al_responder = DEMORA
 
-            if pilas.mundo.control.abajo:
+            if pilas.escena_actual().control.abajo:
                 self.mover_cursor(1)
                 self.demora_al_responder = DEMORA
-            elif pilas.mundo.control.arriba:
+            elif pilas.escena_actual().control.arriba:
                 self.mover_cursor(-1)
                 self.demora_al_responder = DEMORA
 
