@@ -25,17 +25,17 @@ class Nave(Animacion):
     def actualizar(self):
         Animacion.actualizar(self)
 
-        if pilas.mundo.control.izquierda:
+        if pilas.escena_actual().control.izquierda:
             self.rotacion -= self.velocidad
-        elif pilas.mundo.control.derecha:
+        elif pilas.escena_actual().control.derecha:
             self.rotacion += self.velocidad
 
-        if pilas.mundo.control.arriba:
+        if pilas.escena_actual().control.arriba:
             self.avanzar()
 
         self.contador_frecuencia_disparo += 1
 
-        if pilas.mundo.control.boton:
+        if pilas.escena_actual().control.boton:
             if self.contador_frecuencia_disparo > 10:
                 self.contador_frecuencia_disparo = 0
                 self.disparar()
@@ -68,7 +68,7 @@ class Nave(Animacion):
         El argumento cuando_elimina_enemigo tiene que ser una funcion que
         se ejecutara cuando se produzca la colision."""
         self.cuando_elimina_enemigo = cuando_elimina_enemigo
-        pilas.mundo.colisiones.agregar(self.disparos, grupo, self.hacer_explotar_al_enemigo)
+        self.escena.colisiones.agregar(self.disparos, grupo, self.hacer_explotar_al_enemigo)
 
     def hacer_explotar_al_enemigo(self, mi_disparo, el_enemigo):
         "Es el método que se invoca cuando se produce una colisión 'tiro <-> enemigo'"
