@@ -1,4 +1,6 @@
 import os
+import sys
 directorio_actual = os.path.dirname(os.path.abspath(__file__))
 os.chdir(os.path.join(directorio_actual, 'asteroides'))
-from asteroides import ejecutar
+sys.path.insert(0, os.path.join(directorio_actual, 'asteroides'))
+import ejecutar
