@@ -16,8 +16,8 @@ def girar():
 
 pilas.mundo.agregar_tarea_siempre(0.01, girar)
 
-pilas.mundo.camara.x = pilas.utils.interpolar([200, 0], duracion=10)
-pilas.mundo.camara.y = pilas.utils.interpolar([200, 0], duracion=10)
+pilas.escena_actual().camara.x = pilas.utils.interpolar([200, 0], duracion=10)
+pilas.escena_actual().camara.y = pilas.utils.interpolar([200, 0], duracion=10)
 
 pilas.avisar("Moviendo la camara...")
 pilas.ejecutar()
