@@ -6,50 +6,63 @@
 #
 # website - http://www.pilas-engine.com.ar
 
+PPM = 30
+
+import math
 import pilas
-from pilas import colores
 
 try:
     import Box2D as box2d
     contact_listener = box2d.b2ContactListener
+    __enabled__ = True
 except ImportError:
+    __enabled__ = False
     class Tmp:
         pass
     contact_listener = Tmp
-    print "No esta disponible box2d, se deshabilitara la fisica."
 
-import math
+
+def convertir_a_metros(valor):
+    return valor / float(PPM)
+
+def convertir_a_pixels(valor):
+    return valor * PPM
+
+
+def crear_motor_fisica(area, gravedad):
+    if __enabled__:
+        if obtener_version().startswith('2.0'):
+            print "Los siento, el soporte para Box2D version 2.0 se ha eliminado."
+            print "Por favor actualice Box2D a la version 2.1 (ver http://www.pilas-engine.com.ar)."
+            return FisicaDeshabilitada(area, gravedad)
+        else:
+            return Fisica(area, gravedad)
+    else:
+        print "No se pudo iniciar Box2D, se deshabilita el soporte de Fisica."
+        return FisicaDeshabilitada(area, gravedad)
 
 def obtener_version():
     """Obtiene la versión de la biblioteca Box2D"""
     return box2d.__version__
 
-class Fisica(object):
-    """Representa un simulador de mundo fisico, usando la biblioteca box2d."""
 
-    def __init__(self, area, gravedad=(0, -90)):
+class Fisica(object):
+    """Representa un simulador de mundo fisico, usando la biblioteca Box2D (version 2.1)."""
+
+    def __init__(self, area, gravedad):
+        self.mundo = box2d.b2World(gravedad, False)
+        self.objetosContactListener = ObjetosContactListener()
+        self.mundo.contactListener = self.objetosContactListener
+        self.mundo.continuousPhysics = False
+
         self.area = area
-        try:
-            self.escenario = box2d.b2AABB()
-            self.escenario.lowerBound = (-1000.0, -1000.0)
-            self.escenario.upperBound = (1000.0, 1000.0)
-            self.gravedad = box2d.b2Vec2(gravedad[0], gravedad[1])
-            try:
-                self.mundo = box2d.b2World(self.escenario, self.gravedad, True)
-                self.objetosContactListener = ObjetosContactListener()
-                self.mundo.SetContactListener(self.objetosContactListener)
-            except ValueError:
-                print "Solo esta disponible el motor de fisica para box2d 2.0.2b1"
-                raise AttributeError("...")
-        except AttributeError:
-            print "Deshabilitando modulo de fisica (no se encuentra instalado pybox2d en este equipo)"
-            self.mundo = None
-            return
+        self.figuras_a_eliminar = []
 
         self.constante_mouse = None
-        self.i = 0
         self.crear_bordes_del_escenario()
-        self.figuras_a_eliminar = []
+
+        self.velocidad = 1.0
+        self.timeStep = self.velocidad/120.0
 
     def crear_bordes_del_escenario(self):
         self.crear_techo(self.area)
@@ -57,7 +70,7 @@ class Fisica(object):
         self.crear_paredes(self.area)
 
     def reiniciar(self):
-        lista = list(self.mundo.bodyList)
+        lista = list(self.mundo.bodies)
 
         for x in lista:
             self.mundo.DestroyBody(x)
@@ -81,29 +94,67 @@ class Fisica(object):
 
     def actualizar(self, velocidad=1.0):
         if self.mundo:
-            self.mundo.Step(velocidad / 20.0, 10, 8)
-            self.i += 1
+            self.mundo.Step(self.timeStep, 6, 3)
             self._procesar_figuras_a_eliminar()
+            self.mundo.ClearForces()
+
+    def pausar_mundo(self):
+        if self.mundo:
+            self.timeStep = 0
+
+    def reanudar_mundo(self):
+        if self.mundo:
+            self.timeStep = self.velocidad/120.0
 
     def _procesar_figuras_a_eliminar(self):
         "Elimina las figuras que han sido marcadas para quitar."
         if self.figuras_a_eliminar:
             for x in self.figuras_a_eliminar:
                 # Solo elimina las figuras que actualmente existen.
-                if x in self.mundo.bodyList:
+                if x in self.mundo.bodies:
                     self.mundo.DestroyBody(x)
             self.figuras_a_eliminar = []
 
     def dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1):
         "Dibuja todas las figuras en una pizarra. Indicado para depuracion."
-        cuerpos = self.mundo.bodyList
-        cantidad_de_figuras = 0
+
+        cuerpos = self.mundo.bodies
 
         for cuerpo in cuerpos:
+
+            for fixture in cuerpo:
+
+                # cuerpo.type == 0 → estatico
+                # cuerpo.type == 1 → kinematico
+                # cuerpo.type == 2 → dinamico
+
+                shape = fixture.shape
+
+                # TODO: Convertir las coordenadas para que el movimiento de camara se dibuje bien.
+                # TODO: SE puede aplicar a la multiplicacion de transform los PIXELS por metro.
+
+                if isinstance(shape, box2d.b2PolygonShape):
+                    vertices = [cuerpo.transform * v * PPM for v in shape.vertices]
+                    vertices = [pilas.escena_actual().camara.desplazar(v) for v in vertices]
+                    lienzo.poligono(motor, vertices, color=pilas.colores.rojo, grosor=grosor, cerrado=True)
+                elif isinstance(shape, box2d.b2CircleShape):
+                    (x, y) = pilas.escena_actual().camara.desplazar(cuerpo.transform * shape.pos * PPM)
+
+                    lienzo.circulo(motor, x, y, shape.radius * PPM, pilas.colores.rojo, grosor=grosor)
+                else:
+                    # TODO: implementar las figuras de tipo "edge" y "loop".
+                    print "no puedo identificar el tipo de figura."
+
+                #print fixture.shape
+                #print cuerpo.position
+                #print box2d.b2
+
+        """
+        for cuerpo in cuerpos:
+            print cuerpo.position.x
             xform = cuerpo.GetXForm()
 
             for figura in cuerpo.shapeList:
-                cantidad_de_figuras += 1
                 tipo_de_figura = figura.GetType()
 
                 if tipo_de_figura == box2d.e_polygonShape:
@@ -111,14 +162,16 @@ class Fisica(object):
 
                     for v in figura.vertices:
                         pt = box2d.b2Mul(xform, v)
-                        vertices.append((pt.x - pilas.mundo.camara.x, pt.y - pilas.mundo.camara.y))
+                        vertices.append((pt.x - pilas.escena_actual().camara.x, pt.y - pilas.escena_actual().camara.y))
 
-                    lienzo.poligono(motor, vertices, color=colores.rojo, grosor=grosor, cerrado=True)
+                    lienzo.poligono(motor, vertices, color=pilas.colores.rojo, grosor=grosor, cerrado=True)
 
                 elif tipo_de_figura == box2d.e_circleShape:
-                    lienzo.circulo(motor, cuerpo.position.x - pilas.mundo.camara.x, cuerpo.position.y - pilas.mundo.camara.y, figura.radius, colores.rojo, grosor=grosor)
+                    lienzo.circulo(motor, cuerpo.position.x - pilas.escena_actual().camara.x, cuerpo.position.y - pilas.escena_actual().camara.y, figura.radius, pilas.colores.rojo, grosor=grosor)
                 else:
                     print "no puedo identificar el tipo de figura."
+        """
+
 
     def crear_cuerpo(self, definicion_de_cuerpo):
         return self.mundo.CreateBody(definicion_de_cuerpo)
@@ -203,6 +256,18 @@ class Fisica(object):
     def definir_gravedad(self, x, y):
         pilas.fisica.definir_gravedad(x, y)
 
+class FisicaDeshabilitada(object):
+
+    def __init__(self, area, gravedad=None):
+        pass
+
+    def actualizar(self):
+        pass
+
+    def dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1):
+        pass
+
+
 class Figura(object):
     """Representa un figura que simula un cuerpo fisico.
 
@@ -214,31 +279,34 @@ class Figura(object):
         self.id = pilas.utils.obtener_uuid()
 
     def obtener_x(self):
-        return self._cuerpo.position.x
+        return convertir_a_pixels(self._cuerpo.position.x)
 
     def definir_x(self, x):
-        self._cuerpo.SetXForm((x, self.y), self._cuerpo.GetAngle())
+        self._cuerpo.position.x = convertir_a_metros(x)
 
     def obtener_y(self):
-        return self._cuerpo.position.y
+        return convertir_a_pixels(self._cuerpo.position.y)
+
+    def definir_y(self, y):
+        self._cuerpo.position.y = convertir_a_metros(y)
 
     def definir_posicion(self, x, y):
         self.definir_x(x)
         self.definir_y(y)
 
-    def definir_y(self, y):
-        self._cuerpo.SetXForm((self.x, y), self._cuerpo.GetAngle())
-
     def obtener_rotacion(self):
-        return - math.degrees(self._cuerpo.GetAngle())
+        return - math.degrees(self._cuerpo.angle)
 
     def definir_rotacion(self, angulo):
+        # TODO: simplificar a la nueva api.
         self._cuerpo.SetXForm((self.x, self.y), math.radians(-angulo))
 
     def impulsar(self, dx, dy):
-        self._cuerpo.ApplyImpulse((dx, dy), self._cuerpo.GetWorldCenter())
+        # TODO: convertir los valores dx y dy a metros.
+        self._cuerpo.ApplyLinearImpulse((dx, dy), (0, 0))
 
     def obtener_velocidad_lineal(self):
+        # TODO: convertir a pixels
         velocidad = self._cuerpo.GetLinearVelocity()
         return (velocidad.x, velocidad.y)
 
@@ -247,6 +315,7 @@ class Figura(object):
         self.definir_velocidad_lineal(0, 0)
 
     def definir_velocidad_lineal(self, dx=None, dy=None):
+        # TODO: convertir a metros
         anterior_dx, anterior_dy = self.obtener_velocidad_lineal()
 
         if dx is None:
@@ -257,11 +326,12 @@ class Figura(object):
         self._cuerpo.SetLinearVelocity((dx, dy))
 
     def empujar(self, dx=None, dy=None):
+        # TODO: convertir a metros???
         self.definir_velocidad_lineal(dx, dy)
 
     def eliminar(self):
         """Quita una figura de la simulación."""
-        pilas.mundo.fisica.eliminar_figura(self._cuerpo)
+        pilas.escena_actual().fisica.eliminar_figura(self._cuerpo)
 
     x = property(obtener_x, definir_x, doc="define la posición horizontal.")
     y = property(obtener_y, definir_y, doc="define la posición vertical.")
@@ -290,38 +360,33 @@ class Circulo(Figura):
 
         Figura.__init__(self)
 
+        x = convertir_a_metros(x)
+        y = convertir_a_metros(y)
+        radio = convertir_a_metros(radio)
+
         if not fisica:
-            fisica = pilas.mundo.fisica
+            fisica = pilas.escena_actual().fisica
 
-        bodyDef = box2d.b2BodyDef()
-        bodyDef.position=(x, y)
-        bodyDef.linearDamping = amortiguacion
-        bodyDef.fixedRotation = sin_rotacion
-
-        userData = { 'id' : self.id }
-
-        #userData = { 'color' : self.parent.get_color() }
-        #bodyDef.userData = userData
-        #self.parent.element_count += 1
-
-        body = fisica.crear_cuerpo(bodyDef)
-
-        # Create the Body
         if not dinamica:
             densidad = 0
 
-        # Add a shape to the Body
-        circleDef = box2d.b2CircleDef()
-        circleDef.density = densidad
-        circleDef.radius = radio
-        circleDef.restitution = restitucion
-        circleDef.friction = friccion
-        circleDef.userData = userData
+        fixture = box2d.b2FixtureDef(shape=box2d.b2CircleShape(radius=radio),
+                                     density=densidad,
+                                     linearDamping=amortiguacion,
+                                     fixedRotation=sin_rotacion,
+                                     friction=friccion,
+                                     restitution=restitucion)
 
-        body.CreateShape(circleDef)
-        body.SetMassFromShapes()
+        # Agregamos un identificador para controlarlo posteriormente en las
+        # colisiones.
+        userData = { 'id' : self.id }
+        fixture.userData = userData
+
+        if dinamica:
+            self._cuerpo = fisica.mundo.CreateDynamicBody(position=(x, y), fixtures=fixture)
+        else:
+            self._cuerpo = fisica.mundo.CreateStaticBody(position=(x, y), fixtures=fixture)
 
-        self._cuerpo = body
 
 class Rectangulo(Figura):
     """Representa un rectángulo que puede colisionar con otras figuras.
@@ -335,14 +400,40 @@ class Rectangulo(Figura):
     """
 
     def __init__(self, x, y, ancho, alto, dinamica=True, densidad=1.0,
-            restitucion=0.56, friccion=10.5, amortiguacion=0.1,
+            restitucion=0.5, friccion=.2, amortiguacion=0.1,
             fisica=None, sin_rotacion=False):
 
         Figura.__init__(self)
 
-        if not fisica:
-            fisica = pilas.mundo.fisica
+        x = convertir_a_metros(x)
+        y = convertir_a_metros(y)
+        ancho = convertir_a_metros(ancho)
+        alto = convertir_a_metros(alto)
 
+        if not fisica:
+            fisica = pilas.escena_actual().fisica
+
+        if not dinamica:
+            densidad = 0
+
+        fixture = box2d.b2FixtureDef(shape=box2d.b2PolygonShape(box=(ancho/2, alto/2)),
+                                     density=densidad,
+                                     linearDamping=amortiguacion,
+                                     fixedRotation=sin_rotacion,
+                                     friction=friccion,
+                                     restitution=restitucion)
+
+        # Agregamos un identificador para controlarlo posteriormente en las
+        # colisiones.
+        userData = { 'id' : self.id }
+        fixture.userData = userData
+
+        if dinamica:
+            self._cuerpo = fisica.mundo.CreateDynamicBody(position=(x, y), fixtures=fixture)
+        else:
+            self._cuerpo = fisica.mundo.CreateStaticBody(position=(x, y), fixtures=fixture)
+
+        """
         bodyDef = box2d.b2BodyDef()
         bodyDef.position=(x, y)
         bodyDef.linearDamping = amortiguacion
@@ -373,6 +464,7 @@ class Rectangulo(Figura):
         body.SetMassFromShapes()
 
         self._cuerpo = body
+        """
 
 
 class Poligono(Figura):
@@ -395,7 +487,7 @@ class Poligono(Figura):
         Figura.__init__(self)
 
         if not fisica:
-            fisica = pilas.mundo.fisica
+            fisica = pilas.escena_actual().fisica
 
         bodyDef = box2d.b2BodyDef()
         bodyDef.position=puntos[0]
@@ -404,8 +496,11 @@ class Poligono(Figura):
 
         body = fisica.crear_cuerpo(bodyDef)
 
+        # Agregamos un identificador para controlarlo posteriormente en las
+        # colisiones.
         userData = { 'id' : self.id }
-        #bodyDef.userData = userData
+        fixture.userData = userData
+
         # Create the Body
         if not dinamica:
             densidad = 0
@@ -437,25 +532,25 @@ class Poligono(Figura):
 class ConstanteDeMovimiento():
 
     def __init__(self, figura):
-        md = box2d.b2MouseJointDef()
-        mundo = pilas.mundo.fisica.mundo
-        md.body1 = mundo.GetGroundBody()
-        md.body2 = figura._cuerpo
-        md.target = (figura.x, figura.y)
-        md.maxForce = 5000.0 * figura._cuerpo.GetMass()
+        mundo = pilas.escena_actual().fisica.mundo
+        punto_captura = convertir_a_metros(figura.x), convertir_a_metros(figura.y)
+        self.cuerpo_enlazado = mundo.CreateBody()
+        self.figura_cuerpo = figura
+        self.constante = mundo.CreateMouseJoint(bodyA=self.cuerpo_enlazado,
+                bodyB=figura._cuerpo,
+                target=punto_captura,
+                maxForce=1000.0*figura._cuerpo.mass)
 
-        try:
-            self.constante = mundo.CreateJoint(md).getAsType()
-        except:
-            self.constante = mundo.CreateJoint(md)
-
-        figura._cuerpo.WakeUp()
+        figura._cuerpo.awake = True
 
     def mover(self, x, y):
-        self.constante.SetTarget((x, y))
+        self.constante.target = (convertir_a_metros(x), convertir_a_metros(y))
 
     def eliminar(self):
-        pilas.mundo.fisica.mundo.DestroyJoint(self.constante)
+        # Si se intenta destruir un Joint de un cuerpo que ya no existe, se cierra
+        # la aplicación.
+        #pilas.escena_actual().fisica.mundo.DestroyJoint(self.constante)
+        pilas.escena_actual().fisica.mundo.DestroyBody(self.cuerpo_enlazado)
 
 class ConstanteDeDistancia():
     """Representa una distancia fija entre dos figuras.
@@ -474,7 +569,7 @@ class ConstanteDeDistancia():
 
     def __init__(self, figura_1, figura_2, fisica=None, con_colision=True):
         if not fisica:
-            fisica = pilas.mundo.fisica
+            fisica = pilas.escena_actual().fisica
 
         if not isinstance(figura_1, Figura) or not isinstance(figura_2, Figura):
             raise Exception("Las dos figuras tienen que ser objetos de la clase Figura.")
@@ -485,27 +580,26 @@ class ConstanteDeDistancia():
         self.constante = fisica.mundo.CreateJoint(constante)
 
     def eliminar(self):
-        pilas.mundo.fisica.mundo.DestroyJoint(self.constante_mouse)
+        pilas.escena_actual().fisica.mundo.DestroyJoint(self.constante_mouse)
 
-def definir_gravedad(x=0, y=-90):
-    pilas.mundo.fisica.mundo.gravity = (x, y)
+def definir_gravedad(x, y):
+    pilas.escena_actual().fisica.mundo.gravity = (x, y)
 
 class ObjetosContactListener(contact_listener):
 
     def __init__(self):
         box2d.b2ContactListener.__init__(self)
 
-    def Add(self, objetos_colisionados):
-        if (not (objetos_colisionados.shape1.GetUserData() == None)) and (not (objetos_colisionados.shape2.GetUserData() == None)):
-            pilas.mundo.colisiones.verificar_colisiones_fisicas(objetos_colisionados.shape1.GetUserData()['id'], objetos_colisionados.shape2.GetUserData()['id'])
+    def BeginContact(self, *args, **kwargs):
+        """
+        BeginContact(self, b2Contact contact)
 
-    def Persist(self, *args):
-        pass
+        Called when two fixtures begin to touch.
+        """
+        objeto_colisionado_1 = args[0].fixtureA
+        objeto_colisionado_2 = args[0].fixtureB
 
+        if (not objeto_colisionado_1.userData == None) and (not objeto_colisionado_2.userData == None):
+            pilas.escena_actual().colisiones.verificar_colisiones_fisicas(objeto_colisionado_1.userData['id'],
+                                                                          objeto_colisionado_2.userData['id'])
 
-    def Remove(self, *args):
-        pass
-
-
-    def Result(self, *args):
-        pass
