@@ -26,15 +26,15 @@ class RebotarComoPelota(Habilidad):
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
         error = random.randint(-10, 10) / 10.0
-        
-        circulo = pilas.fisica.Circulo(receptor.x + error, 
-                                       receptor.y + error, 
+
+        circulo = pilas.fisica.Circulo(receptor.x + error,
+                                       receptor.y + error,
                                        receptor.radio_de_colision)
         receptor.aprender(pilas.habilidades.Imitar, circulo)
         self.circulo = circulo
         receptor.impulsar = self.impulsar
         receptor.empujar = self.empujar
-        
+
     def eliminar(self):
         self.circulo.eliminar()
 
@@ -49,8 +49,8 @@ class RebotarComoCaja(Habilidad):
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
         error = random.randint(-10, 10) / 10.0
-        rectangulo = pilas.fisica.Rectangulo(receptor.x + error, 
-                                             receptor.y + error, 
+        rectangulo = pilas.fisica.Rectangulo(receptor.x + error,
+                                             receptor.y + error,
                                              receptor.radio_de_colision*2 - 4,
                                              receptor.radio_de_colision*2 - 4,
                                              )
@@ -59,13 +59,13 @@ class RebotarComoCaja(Habilidad):
 
     def eliminar(self):
         self.rectangulo.eliminar()
-        
-        
+
+
 class ColisionableComoPelota(RebotarComoPelota):
 
     def __init__(self, receptor):
         RebotarComoPelota.__init__(self, receptor)
-        
+
     def actualizar(self):
         self.figura.body.position.x = self.receptor.x
         self.figura.body.position.y = self.receptor.y
@@ -78,7 +78,7 @@ class SeguirAlMouse(Habilidad):
 
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
-        pilas.eventos.mueve_mouse.conectar(self.mover)
+        pilas.escena_actual().mueve_mouse.conectar(self.mover)
 
     def mover(self, evento):
         self.receptor.x = evento.x
@@ -89,7 +89,7 @@ class AumentarConRueda(Habilidad):
 
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
-        pilas.eventos.mueve_rueda.conectar(self.cambiar_de_escala)
+        pilas.escena_actual().mueve_rueda.conectar(self.cambiar_de_escala)
 
     def cambiar_de_escala(self, evento):
         self.receptor.escala += (evento.delta / 4.0)
@@ -100,7 +100,7 @@ class SeguirClicks(Habilidad):
 
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
-        pilas.eventos.click_de_mouse.conectar(self.moverse_a_este_punto)
+        pilas.escena_actual().click_de_mouse.conectar(self.moverse_a_este_punto)
 
     def moverse_a_este_punto(self, evento):
         self.receptor.x = [evento.x], 0.5
@@ -120,35 +120,35 @@ class Arrastrable(Habilidad):
 
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
-        pilas.eventos.click_de_mouse.conectar(self.cuando_intenta_arrastrar)
+        pilas.escena_actual().click_de_mouse.conectar(self.cuando_intenta_arrastrar)
 
     def cuando_intenta_arrastrar(self, evento):
         "Intenta mover el objeto con el mouse cuando se pulsa sobre el."
         if self.receptor.colisiona_con_un_punto(evento.x, evento.y):
-            pilas.eventos.termina_click.conectar(self.cuando_termina_de_arrastrar)
-            pilas.eventos.mueve_mouse.conectar(self.cuando_arrastra, id='cuando_arrastra')
+            pilas.escena_actual().termina_click.conectar(self.cuando_termina_de_arrastrar)
+            pilas.escena_actual().mueve_mouse.conectar(self.cuando_arrastra, id='cuando_arrastra')
             self.comienza_a_arrastrar()
 
     def cuando_arrastra(self, evento):
         "Arrastra el actor a la posicion indicada por el puntero del mouse."
         if self._el_receptor_tiene_fisica():
-            pilas.mundo.fisica.cuando_mueve_el_mouse(evento.x, evento.y)
+            pilas.escena_actual().fisica.cuando_mueve_el_mouse(evento.x, evento.y)
         else:
             self.receptor.x += evento.dx
             self.receptor.y += evento.dy
 
     def cuando_termina_de_arrastrar(self, evento):
         "Suelta al actor porque se ha soltado el botón del mouse."
-        pilas.eventos.mueve_mouse.desconectar_por_id(id='cuando_arrastra')
+        pilas.escena_actual().mueve_mouse.desconectar_por_id(id='cuando_arrastra')
         self.termina_de_arrastrar()
 
     def comienza_a_arrastrar(self):
         if self._el_receptor_tiene_fisica():
-            pilas.mundo.fisica.capturar_figura_con_el_mouse(self.receptor.figura)
+            pilas.escena_actual().fisica.capturar_figura_con_el_mouse(self.receptor.figura)
 
     def termina_de_arrastrar(self):
         if self._el_receptor_tiene_fisica():
-            pilas.mundo.fisica.cuando_suelta_el_mouse()
+            pilas.escena_actual().fisica.cuando_suelta_el_mouse()
 
     def _el_receptor_tiene_fisica(self):
         return hasattr(self.receptor, 'figura')
@@ -159,11 +159,11 @@ class MoverseConElTeclado(Habilidad):
 
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
-        pilas.eventos.actualizar.conectar(self.on_key_press)
+        pilas.escena_actual().actualizar.conectar(self.on_key_press)
 
     def on_key_press(self, evento):
         velocidad = 5
-        c = pilas.mundo.control
+        c = pilas.escena_actual().control
 
         if c.izquierda:
             self.receptor.x -= velocidad
@@ -195,19 +195,22 @@ class SeMantieneEnPantalla(Habilidad):
 
     Si el actor sale por la derecha de la pantalla, entonces regresa
     por la izquiera. Si sale por arriba regresa por abajo y asi..."""
+    def __init__(self, receptor):
+        Habilidad.__init__(self, receptor)
+        self.ancho, self.alto = pilas.mundo.motor.obtener_area()
 
     def actualizar(self):
         # Se asegura de regresar por izquierda y derecha.
-        if self.receptor.derecha < -320:
-            self.receptor.izquierda = 320
-        elif self.receptor.izquierda > 320:
-            self.receptor.derecha = -320
+        if self.receptor.derecha < -(self.ancho/2):
+            self.receptor.izquierda = (self.ancho/2)
+        elif self.receptor.izquierda > (self.ancho/2):
+            self.receptor.derecha = -(self.ancho/2)
 
         # Se asegura de regresar por arriba y abajo.
-        if self.receptor.abajo > 240:
-            self.receptor.arriba = -240
-        elif self.receptor.arriba < -240:
-            self.receptor.abajo = 240
+        if self.receptor.abajo > (self.alto/2):
+            self.receptor.arriba = -(self.alto/2)
+        elif self.receptor.arriba < -(self.alto/2):
+            self.receptor.abajo = (self.alto/2)
 
 
 class PisaPlataformas(Habilidad):
@@ -215,8 +218,8 @@ class PisaPlataformas(Habilidad):
     def __init__(self, receptor):
         Habilidad.__init__(self, receptor)
         error = random.randint(-10, 10) / 10.0
-        self.figura = pilas.fisica.fisica.crear_figura_cuadrado(receptor.x + error, 
-                                                               receptor.y + error, 
+        self.figura = pilas.fisica.fisica.crear_figura_cuadrado(receptor.x + error,
+                                                               receptor.y + error,
                                                                receptor.radio_de_colision,
                                                                masa=10,
                                                                elasticidad=0,
@@ -238,8 +241,18 @@ class Imitar(Habilidad):
     def __init__(self, receptor, objeto_a_imitar, con_rotacion=True):
         Habilidad.__init__(self, receptor)
         self.objeto_a_imitar = objeto_a_imitar
-        receptor.figura = objeto_a_imitar
+
+        # Establecemos el mismo id para el actor y el objeto fisico
+        # al que imita. Así luego en las colisiones fisicas sabremos a que
+        # actor corresponde esa colisión.
         receptor.id = objeto_a_imitar.id
+
+        # Y nos guardamos una referencia al objeto físico al que imita.
+        # Posterormente en las colisiones fisicas comprobaremos si el
+        # objeto tiene el atributo "figura" para saber si estamos delante
+        # de una figura fisica o no.
+        receptor.figura = objeto_a_imitar
+
         self.con_rotacion = con_rotacion
 
     def actualizar(self):
