@@ -6,7 +6,6 @@
 #
 # Website - http://www.pilas-engine.com.ar
 import os
-import shutil
 import interpolaciones
 import sys
 import subprocess
@@ -14,29 +13,11 @@ import math
 import uuid
 
 import pilas
-import xmlreader
 
 
 PATH = os.path.dirname(os.path.abspath(__file__))
 
 
-def cargar_autocompletado():
-    "Carga los modulos de python para autocompletar desde la consola interactiva."
-    try:
-        import rlcompleter
-        import readline
-
-        readline.parse_and_bind("tab: complete")
-    except ImportError:
-        print "No se puede cargar el autocompletado, instale readline..."
-
-def hacer_flotante_la_ventana():
-    "Hace flotante la ventana para i3 (el manejador de ventanas que utiliza hugo...)"
-    try:
-        subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    except OSError:
-        pass
-
 def es_interpolacion(an_object):
     "Indica si un objeto se comporta como una colisión."
 
@@ -96,14 +77,6 @@ def colisionan(a, b):
     "Retorna True si dos actores estan en contacto."
     return distancia_entre_dos_actores(a, b) < a.radio_de_colision + b.radio_de_colision
 
-def crear_juego():
-    nombre = raw_input("Indica el nombre del juego: ")
-    shutil.copytree(PATH + "/data/juegobase", nombre)
-
-    print "Se ha creado el directorio '%s'" %(nombre)
-    print "Ingresa en el directorio y econtrarás los archivos iniciales del juego."
-
-
 def interpolable(f):
     "Decorador que se aplica a un metodo para que permita animaciones de interpolaciones."
 
@@ -123,7 +96,7 @@ def interpolable(f):
             value = interpolar(value, duracion=duracion)
         elif isinstance(value, xrange):
             value = interpolar(list(value), duracion=duracion)
-            
+
         if es_interpolacion(value):
             value.apply(args[0], function=f.__name__)
         else:
@@ -140,8 +113,8 @@ def hacer_coordenada_pantalla_absoluta(x, y):
     return (x + dx, dy - y)
 
 def listar_actores_en_consola():
-    todos = pilas.actores.todos
-    
+    todos = pilas.escena_actual().actores
+
     print "Hay %d actores en la escena:" %(len(todos))
     print ""
 
@@ -165,10 +138,10 @@ def convertir_de_posicion_fisica_relativa(x, y):
 
 def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
     """Retorna un objeto que representa cambios de atributos progresivos.
-    
+
     El resultado de esta función se puede aplicar a varios atributos
     de los actores, por ejemplo::
-        
+
         bomba = pilas.actores.Bomba()
         bomba.escala = pilas.interpolar(3)
 
@@ -215,11 +188,10 @@ def realizar_pruebas():
 
     print "Box 2D:",
 
-    try:
-        import Box2D as box2d
-        print "OK, versión", box2d.__version__
-    except ImportError:
-        print "Error -> no se encuentra pybox2d."
+    if pilas.fisica.obtener_version().startswith("2.1"):
+        print "OK, versión", pilas.fisica.obtener_version()
+    else:
+        print "Error -> la versión está obsoleta, instale una versión de la serie 2.1"
 
     print "pyqt:",
 
@@ -238,6 +210,14 @@ def realizar_pruebas():
     except ImportError:
         print "Error -> no se encuentra pyqt4gl."
 
+    print "PIL para soporte de jpeg (opcional):",
+
+    try:
+        from PIL import Image
+        print "OK"
+    except ImportError:
+        print "Cuidado -> no se encuentra PIL."
+
 def ver_codigo(objeto, imprimir, retornar):
     """Imprime en pantalla el codigo fuente asociado a un objeto."""
     import inspect
@@ -254,4 +234,34 @@ def ver_codigo(objeto, imprimir, retornar):
         return codigo
 
 def obtener_uuid():
-    return str(uuid.uuid4())
\ No newline at end of file
+    return str(uuid.uuid4())
+
+def abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo):
+    if sys.platform.startswith('darwin'):
+        subprocess.call(('open', ruta_al_archivo))
+    elif os.name == 'nt':
+        os.startfile(ruta_al_archivo)
+    elif os.name == 'posix':
+        subprocess.call(('xdg-open', ruta_al_archivo))
+
+def centrar_ventana(widget):
+    from PyQt4 import QtGui
+    desktop = QtGui.QApplication.desktop()
+    widget.move(desktop.screen().rect().center() - widget.rect().center())
+
+def descargar_archivo_desde_internet(parent, url, archivo_destino):
+    import descargar
+    ventana = descargar.Descargar(parent, url, archivo_destino)
+    ventana.show()
+
+def imprimir_todos_los_eventos():
+    "Muestra en consola los eventos activos y a quienes invocan"
+    import pilas
+
+    for x in dir(pilas.escena_actual()):
+        attributo = getattr(pilas.escena_actual(), x)
+
+        if isinstance(attributo, pilas.evento.Evento):
+            print "Evento:", attributo.nombre
+            attributo.imprimir_funciones_conectadas()
+            print ""
